"""Base class for DIN station objects."""

from dataclasses import dataclass

from .station_object import StationObject


@dataclass
class DINStation(StationObject):
    """Base class for DIN station objects."""



"""BackBox object."""

from dataclasses import dataclass, field

from .location_object import LocationObject


@dataclass
class BackBox(LocationObject):
    """BackBox object."""

    keypad_style: int = field(
        metadata={
            "name": "KeypadStyle",
        }
    )
